var gphoto2_filesys_8c =
[
    [ "_CameraFilesystemFile", "struct__CameraFilesystemFile.html", null ],
    [ "_CameraFilesystemFolder", "struct__CameraFilesystemFolder.html", null ],
    [ "_CameraFilesystem", "struct__CameraFilesystem.html", null ],
    [ "PICTURES_TO_KEEP", "gphoto2-filesys_8c.html#a46c32fb69d164f5f877338014825d318", null ],
    [ "gp_filesystem_count", "gphoto2-filesys_8c.html#a7fdf2e5f1c7fda4b0f7f58f45a33c71c", null ],
    [ "gp_filesystem_delete_all", "gphoto2-filesys_8c.html#a6b6fc659abe86a1724fe6600d112931f", null ],
    [ "gp_filesystem_delete_file", "gphoto2-filesys_8c.html#a4d1424f4d45018dc892a2da792822f0c", null ],
    [ "gp_filesystem_delete_file_noop", "gphoto2-filesys_8c.html#aa6cd62861b01c157efcdf25dd2753576", null ],
    [ "gp_filesystem_dump", "gphoto2-filesys_8c.html#a0e785e85f4a199ee87dfd7604ad8d45a", null ],
    [ "gp_filesystem_free", "gphoto2-filesys_8c.html#a08fa6e05d77adce0b6be853c226dedaa", null ],
    [ "gp_filesystem_get_file", "gphoto2-filesys_8c.html#a7bbfa59b2587d36fa5be529c788f9585", null ],
    [ "gp_filesystem_get_folder", "gphoto2-filesys_8c.html#a083ea3fd7f794f6de09c1c51ba142572", null ],
    [ "gp_filesystem_get_info", "gphoto2-filesys_8c.html#ac58c62bed856f6b143aaa776d74b5705", null ],
    [ "gp_filesystem_get_storageinfo", "gphoto2-filesys_8c.html#af706b65998fe5f7c7bebd386b941c778", null ],
    [ "gp_filesystem_list_files", "gphoto2-filesys_8c.html#a97c3a1cb9996eb8319d232023209bf19", null ],
    [ "gp_filesystem_list_folders", "gphoto2-filesys_8c.html#ae6106ac2f70f59b50525a8de870ec25b", null ],
    [ "gp_filesystem_make_dir", "gphoto2-filesys_8c.html#a42bad7d5fc4433d353f1d336f575c340", null ],
    [ "gp_filesystem_name", "gphoto2-filesys_8c.html#ab22748e14f4e4d0492c4ddeeec557e70", null ],
    [ "gp_filesystem_new", "gphoto2-filesys_8c.html#a3c12781d176e73fb9e8795d29e64f56e", null ],
    [ "gp_filesystem_number", "gphoto2-filesys_8c.html#af9cb8b2135e3eaf71ee864fed2d56212", null ],
    [ "gp_filesystem_put_file", "gphoto2-filesys_8c.html#ae1e4bab15af84be9873bbd14b383da25", null ],
    [ "gp_filesystem_read_file", "gphoto2-filesys_8c.html#aed55d9d55663c0cc58f002a176ad2aa4", null ],
    [ "gp_filesystem_remove_dir", "gphoto2-filesys_8c.html#af55d08507d98adf2b02d1efe5f78623d", null ],
    [ "gp_filesystem_reset", "gphoto2-filesys_8c.html#a57f7b7038489eadd5a78787d6cfe8d66", null ],
    [ "gp_filesystem_set_file_noop", "gphoto2-filesys_8c.html#a7ee1e023cac99c0e96d28954bd626b19", null ],
    [ "gp_filesystem_set_funcs", "gphoto2-filesys_8c.html#a6f6d981b8ab1273e8048df66670782ab", null ],
    [ "gp_filesystem_set_info", "gphoto2-filesys_8c.html#a3ffbe7ac58a11c688edd98369741f828", null ],
    [ "gp_filesystem_set_info_dirty", "gphoto2-filesys_8c.html#a660a952a1107a18da00614d1a48fc2e5", null ],
    [ "gp_filesystem_set_info_noop", "gphoto2-filesys_8c.html#a4e4ea8548673cc56c465ee447dd916f3", null ]
];